@@ -10,7 +10,7 @@ use Jcode;
 use vars qw($VERSION @ISA);
 @ISA = qw(Spreadsheet::ParseExcel::FmtDefault Exporter);
 
-$VERSION = '0.02'; # 
+$VERSION = '0.03'; # 
 my %hFmtJapan = (
     0x00 => '@',
     0x01 => '0',
@@ -35,7 +35,14 @@ my %hFmtJapan = (
     0x13 => 'h:mm:ss AM/PM',
     0x14 => 'h:mm',
     0x15 => 'h:mm:ss',
-    0x16 => 'm/d/yy h:mm',
+#    0x16 => 'm/d/yy h:mm',
+    0x16 => 'yyyy/m/d h:mm',
+
+#0x17-0x24 -- Differs in Natinal
+    0x1E => 'm/d/yy',
+    0x1F => 'yyyy"ǯ"m""d""',
+    0x20 => 'h""mm"ʬ"',
+    0x21 => 'h""mm"ʬ"ss""',
 #0x17-0x24 -- Differs in Natinal
     0x25 => '(#,##0_);(#,##0)',
     0x26 => '(#,##0_);[RED](#,##0)',
@@ -50,8 +57,13 @@ my %hFmtJapan = (
     0x2F => 'mm:ss.0',
     0x30 => '##0.0E+0',
     0x31 => '@',
-);
 
+    0x37 => 'yyyy"ǯ"m""',        
+    0x38 => 'm""d""',       
+    0x39 => 'ge.m.d',
+    0x3A => 'ggge"ǯ"m""d""',
+);
+my $_Code;
 #------------------------------------------------------------------------------
 # new (for Spreadsheet::ParseExcel::FmtJapan)
 #------------------------------------------------------------------------------
@@ -60,6 +72,13 @@ sub new($%) {
     my $oThis={ 
         Code => $hKey{Code},
     };
+    if($oThis->{Code}) {
+        foreach my $sKey (keys %hFmtJapan) {
+            $hFmtJapan{$sKey} = 
+                Jcode::convert($hFmtJapan{$sKey}, $oThis->{Code}, 'euc');
+        }
+        $_Code = $oThis->{Code};
+    }
     bless $oThis;
     return $oThis;
 }
@@ -68,7 +87,7 @@ sub new($%) {
 #------------------------------------------------------------------------------
 sub TextFmt($$;$) {
     my($oThis, $sTxt, $sCode) =@_;
-#    $sCode = 'sjis' if(defined($sCode) && ($sCode eq '_native_'));
+
     $sCode = 'sjis' if((! defined($sCode)) || ($sCode eq '_native_'));
     if($oThis->{Code}) {
         return Jcode::convert($sTxt, $oThis->{Code}, $sCode);
@@ -78,11 +97,18 @@ sub TextFmt($$;$) {
     }
 }
 #------------------------------------------------------------------------------
+# FmtStringDef (for Spreadsheet::ParseExcel::FmtJapan)
+#------------------------------------------------------------------------------
+sub FmtStringDef($$$) {
+    my($oThis, $iFmtIdx, $oBook) =@_;
+    return $oThis->SUPER::FmtStringDef($iFmtIdx, $oBook, \%hFmtJapan);
+}
+#------------------------------------------------------------------------------
 # ValFmt (for Spreadsheet::ParseExcel::FmtJapan)
 #------------------------------------------------------------------------------
 sub ValFmt($$$) {
     my($oThis, $oCell, $oBook) =@_;
-    return $oThis->SUPER::ValFmt($oCell, $oBook, \%hFmtJapan);
+    return $oThis->SUPER::ValFmt($oCell, $oBook);
 }
 #------------------------------------------------------------------------------
 # ChkType (for Spreadsheet::ParseExcel::FmtJapan)
@@ -92,4 +118,32 @@ sub ChkType($$$) {
 # Is there something special for Japan?
     return $oPkg->SUPER::ChkType($iNumeric, $iFmtIdx);
 }
+#------------------------------------------------------------------------------
+# CnvNengo (for Spreadsheet::ParseExcel::FmtJapan)
+#------------------------------------------------------------------------------
+sub CnvNengo($@) {
+    my($iKind, @aTime) = @_;
+    my $iWk = sprintf('%04d%02d%02d', $aTime[5], $aTime[4], $aTime[3]);
+    if($iWk    lt '19120730') {
+        my $iY = $aTime[5] - 1867;
+        return ($iKind == 1)? "M$iY" : 
+                Jcode::convert("$iY", $_Code, 'euc');
+    }
+    elsif($iWk lt '19261225') {
+        my $iY = $aTime[5] - 1911;
+        return ($iKind == 1)? "T$iY" : 
+                Jcode::convert("$iY", $_Code, 'euc');
+    }
+    elsif($iWk lt '19890108' ) {
+        my $iY = $aTime[5] - 1925;
+        return ($iKind == 1)? "S$iY" : 
+                Jcode::convert("$iY", $_Code, 'euc');
+    }
+    else {
+        my $iY = $aTime[5] - 1988;
+        return ($iKind == 1)? "H$iY" :
+                Jcode::convert("ʿ$iY", $_Code, 'euc');
+    }
+}
+
 1;
